Classification

Enum Classification 

pub enum Classification {
    VaccineProof,
    Waiver,
    Photo,
    MedicalRecord,
    IncidentEvidence,
    Other,
}
Document classification used to route vaccine, waiver, medical, photo, and incident evidence.

Variants



VaccineProof

Vaccine proof document classification or pipeline state used for review and retention.



Waiver

Waiver document classification or pipeline state used for review and retention.



Photo

Photo document classification or pipeline state used for review and retention.



MedicalRecord

Medical record document classification or pipeline state used for review and retention.



IncidentEvidence

Incident evidence document classification or pipeline state used for review and retention.



Other

Non-dog, non-cat pet handled by exception policy.