pub enum VirusScanStatus {
Pending,
Passed,
Failed,
Unsupported,
}Expand description
Virus-scan outcome used before documents may become staff-visible evidence.
Variants
Pending
Pending document classification or pipeline state used for review and retention.
Passed
Passed document classification or pipeline state used for review and retention.
Failed
Deposit collection was attempted but did not succeed.
Unsupported
Unsupported document classification or pipeline state used for review and retention.